Filter to keep only schools (remove district-only rows)
Source:R/fetch_directory.R
filter_schools_only.RdSEDREF reports include both districts and schools. District rows typically have school code ending in 000000.
R/fetch_directory.R
filter_schools_only.RdSEDREF reports include both districts and schools. District rows typically have school code ending in 000000.