Skip to contents

Returns a vector of years for which graduation rate data is available from the New York State Education Department.

Usage

get_available_grad_years()

Value

Integer vector of years (2014-2024)

Examples

if (FALSE) { # \dontrun{
get_available_grad_years()
# Returns: 2014 2015 2016 ... 2024
} # }