Adds boolean flags to identify state, district, and school level records. This is typically called automatically by fetch_enr, but can be used to re-identify aggregation levels after filtering.
Adds boolean flags to identify state, district, and school level records. This is typically called automatically by fetch_enr, but can be used to re-identify aggregation levels after filtering.