R/get_raw_graduation.R
get_available_grad_years.Rd
Returns a vector of years for which graduation rate data is available from the New York State Education Department.
get_available_grad_years()
Integer vector of years (2014-2024)
if (FALSE) { # \dontrun{ get_available_grad_years() # Returns: 2014 2015 2016 ... 2024 } # }